function [x,y]=simul_SS_model(A,B,C,D,Sigma_v,Sigma_w,u,x_0)
% simulace modelu ve state-space tvaru
% x(t+1)=Ax(t) + Bu(t) + v(t)
%   y(t)=Cx(t) + Du(t) + w(t)
% vstupy: A,B,C,D matice state-space tvaru modelu
%         u ... hodnoty exogennich velicin
%         Sigma_v ... kovariancni matice sumu procesu
%         Sigma_w ... kovariancni matice sumu mereni
%         x_0 ... pocatecni hodnota
%         u ... matece exogennich promennych (bude generovano tolik hodnot,
%         kolik ma tato matice sloupcu)


T=size(u,2);

n_x=length(A);
n_y=size(C,1);

v=mvnrnd(zeros(T-1,n_x),Sigma_v)'; %vygenerovani sumu procesu
w=mvnrnd(zeros(T,n_y),Sigma_w)'; %vygenerovani sumu mereni

x=zeros(n_x,T);
y=zeros(n_y,T);
x(:,1)=x_0;
y(:,1)=C*x_0+D*u(:,1)+w(:,1);
for t=1:T-1
    x(:,t+1)=A*x(:,t)+B*u(:,t)+v(:,t);
    y(:,t+1)=C*x(:,t+1)+D*u(:,t+1)+w(:,t+1);
end
      
